Installation
============

Installing from prepackaged binaries
------------------------------------

Stable releases of ContourPy are available from `PyPI`_, `conda-forge`_, and Anaconda
`default`_ channels for Linux, macOS and Windows.

#. To install from `PyPI`_:

   .. code-block:: bash

      $ pip install contourpy

#. To install from `conda-forge`_:

   .. code-block:: bash

      $ conda install -c conda-forge contourpy

#. To install from Anaconda `default`_ channel:

   .. code-block:: bash

      $ conda install contourpy

The only compulsory runtime dependency is `NumPy`_.

If you want to make use of one of ContourPy's utility renderers in the :mod:`contourpy.util` module
you will also have to install either `Matplotlib`_ or `Bokeh`_.

Installing from source
----------------------

If you wish to install from source code, see the :ref:`developer_guide`.
